@@ -1,10 +1,10 @@
 #!/bin/bash
 # Build config for build.sh
 APP_NAME=ubufox
-CHROME_PROVIDERS="content locale"
+CHROME_PROVIDERS="content locale res"
 CLEAN_UP=1
 ROOT_FILES=
-ROOT_DIRS="scripts defaults components modules"
+ROOT_DIRS="scripts defaults components"
 BEFORE_BUILD=
 BEFORE_PACK=
 AFTER_BUILD=
