@@ -50,46 +50,89 @@ if (!com.ubuntu) com.ubuntu = {};
 
     addNotificationToBrowser: function URL_addNotificationToBrowser(aBrowser,
                                                                     aRaised) {
-      PopupNotifications.show(aBrowser, "ubufox-restart-request",
-                              this.restartNotificationLabel,
-                              "ubufox-restart-notification-icon",
-                              {label: this.restartNotificationButton,
-                               accessKey: this.restartNotificationKey,
-                               callback: function() {
-        gBrowser.tabContainer.removeEventListener("TabOpen",
-                                                  UpdateRestartListener.onTabOpen,
-                                                  false);
-        gBrowser.browsers.forEach(function(browser) {
-          let notification = PopupNotifications.getNotification("ubufox-restart-request",
-                                                                browser);
-          if (notification) {
-            PopupNotifications.remove(notification);
-          }
-        });
+      if (this.notificationStyle == "popup") {
+        PopupNotifications.show(aBrowser, "ubufox-restart-request",
+                                this.restartNotificationLabel,
+                                "ubufox-restart-notification-icon",
+                                {label: this.restartNotificationButton,
+                                 accessKey: this.restartNotificationKey,
+                                 callback: (function() {
+          gBrowser.tabContainer.removeEventListener("TabOpen",
+                                                    this.onTabOpen,
+                                                    false);
+          gBrowser.browsers.forEach(function(browser) {
+            let notification = PopupNotifications.getNotification("ubufox-restart-request",
+                                                                  browser);
+            if (notification) {
+              PopupNotifications.remove(notification);
+            }
+          });
 
-        Cc["@mozilla.org/toolkit/app-startup;1"].getService(Ci.nsIAppStartup)
-                                                .quit(Ci.nsIAppStartup.eRestart |
-                                                      Ci.nsIAppStartup.eAttemptQuit);
-      }},
-                              [], {dismissed: aRaised ? false : true,
-                                   timeout: 8.64e15});
+          Cc["@mozilla.org/toolkit/app-startup;1"].getService(Ci.nsIAppStartup)
+                                                  .quit(Ci.nsIAppStartup.eRestart |
+                                                        Ci.nsIAppStartup.eAttemptQuit);
+        }).bind(this)},
+                                [], {dismissed: aRaised ? false : true,
+                                     timeout: 8.64e15});
+      } else if (this.notificationStyle == "infobar") {
+        let notificationBox = gBrowser.getNotificationBox(aBrowser);
+        let notification = notificationBox
+                           .getNotificationWithValue("notification-restart");
+        if (!notification) {
+          notificationBox.appendNotification(this.oldRestartNotificationLabel,
+                                             "notification-restart", "",
+                                             notificationBox.PRIORITY_WARNING_LOW,
+                                             [{ label: this.restartNotificationButton,
+                                                accessKey: this.restartNotificationKey,
+                                                callback: (function() {
+            gBrowser.tabContainer.removeEventListener("TabOpen",
+                                                      this.onTabOpen,
+                                                      false);
+            gBrowser.browsers.forEach(function(browser) {
+              let notificationBox = gBrowser.getNotificationBox(browser);
+              let notification = notificationBox
+                                 .getNotificationWithValue("notification-restart");
+              if (notification) {
+                notificationBox.removeNotification(notification);
+              }
+            });
+
+            if (this.intervalId) {
+              window.clearInterval(this.intervalId);
+            }
+
+            Cc["@mozilla.org/toolkit/app-startup;1"].getService(Ci.nsIAppStartup)
+                                                    .quit(Ci.nsIAppStartup.eRestart |
+                                                          Ci.nsIAppStartup.eAttemptQuit);
+          }).bind(this)}]);
+        }
+      }
     },
 
     onTabOpen: function URL_onTabOpen(aEvent) {
-      setTimeout(function() {
+      window.setTimeout(function() {
         UpdateRestartListener.addNotificationToBrowser(gBrowser.getBrowserForTab(aEvent.target),
                                                        false);
       }, 0);
     },
 
+    displayNotifications: function URL_displayNotifications() {
+      gBrowser.browsers.forEach(function(browser) {
+        this.addNotificationToBrowser(browser,
+                                      browser == gBrowser.selectedBrowser ?
+                                       true : false);
+      }, this);
+    },
+
     requestRestart: function URL_requestRestart() {
       if (!this.restartRequested) {
         gBrowser.tabContainer.addEventListener("TabOpen", this.onTabOpen, false);
-        gBrowser.browsers.forEach(function(browser) {
-          this.addNotificationToBrowser(browser,
-                                        browser == gBrowser.selectedBrowser ?
-                                        true : false);
-        }, this);
+        this.displayNotifications();
+
+        if (this.notificationStyle == "infobar") {
+          this.intervalId = window.setInterval(this.displayNotifications.bind(this),
+                                               900000);
+        }
 
         this.restartRequested = true;
       }
@@ -100,10 +143,29 @@ if (!com.ubuntu) com.ubuntu = {};
     },
 
     onPluginsUpdated: function URL_onPluginsUpdated() {
-      this.requestRestart();
+      if (this.notificationStyle == "popup") {
+        this.requestRestart();
+      }
     }
   };
 
+  XPCOMUtils.defineLazyGetter(UpdateRestartListener,
+                              "notificationStyle",
+                              function() {
+    try {
+      return Services.prefs.getCharPref("extensions.ubufox.update-restart-notification-style");
+    } catch(e) {
+      return distro.updateRestartNotificationStyle;
+    }
+  });
+
+  XPCOMUtils.defineLazyGetter(UpdateRestartListener,
+                              "oldRestartNotificationLabel",
+                              function() {
+    return document.getElementById("ubufox-restart-strings")
+                   .getString("oldRestartNotificationLabel");
+  });
+
   XPCOMUtils.defineLazyGetter(UpdateRestartListener,
                               "restartNotificationLabel",
                               function() {
