@@ -94,10 +94,8 @@ function nsPluginInstallerWizard() {
   //        so we can notify which browser can be reloaded.
 
   if ("arguments" in window) {
-    for (var item in window.arguments[0].plugins){
-      this.mPluginRequestArray[window.arguments[0].plugins[item].mimetype] =
-        new nsPluginRequest(window.arguments[0].plugins[item]);
-
+    for (let [mimetype, pluginInfo] of window.arguments[0].plugins) {
+      this.mPluginRequestArray[mimetype] = pluginInfo;
       this.mPluginRequestArrayLength++;
     }
 
@@ -691,11 +689,6 @@ nsPluginInstallerWizard.prototype.getChromeLocale = function() {
             .getService(nsIXULChromeRegistry).getSelectedLocale("global");
 }
 
-function nsPluginRequest(aPlugRequest) {
-  this.mimetype = encodeURI(aPlugRequest.mimetype);
-  this.pluginsPage = aPlugRequest.pluginsPage;
-}
-
 var gPluginInstaller;
 
 function wizardInit() {
